package pay.platform.api.system.controller;

import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.Parameters;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springdoc.core.annotations.ParameterObject;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import pay.platform.api.system.model.query.PayMerchantQuery;
import pay.platform.api.system.model.vo.PayMerchantVO;
import pay.platform.api.system.servcie.PayMerchantService;
import pay.platform.core.common.Result;
import pay.platform.core.common.domain.BasePage;
import pay.platform.domain.PayMerchant;

import java.io.Serializable;
import java.util.List;

/**
 * 商户 控制层。
 *
 * @author mybatis-flex-helper automatic generation
 * @since 1.0
 */
@RestController
@RequestMapping("/sys/pay/merchant")
@Tag(name = "商户控制层")
public class PayMerchantController {

    @Autowired
    private PayMerchantService PayMerchantService;

    /**
     * 添加 商户
     *
     * @param PayMerchant 商户
     * @return Result.OK({ @ code true } 添加成功 ， { @ code false } 添加失败
     */
    @PostMapping("/save")
    @Operation(summary = "添加商户")

    public Result<Boolean> save(@RequestBody PayMerchant PayMerchant) {
        return Result.OK(PayMerchantService.saveMerchant(PayMerchant));
    }


    /**
     * 根据主键删除商户
     *
     * @param id 主键
     * @return Result.OK({ @ code true } 删除成功 ， { @ code false } 删除失败
     */
    @DeleteMapping("/remove/{id}")
    @Operation(summary = "根据主键删除商户")
    @Parameters(value = {
            @Parameter(name = "id", description = "id", required = true)
    })
    public Result<Boolean> remove(@PathVariable Serializable id) {
        return Result.OK(PayMerchantService.removeById(id));
    }


    /**
     * 根据主键更新商户
     *
     * @param PayMerchant 商户
     * @return Result.OK({ @ code true } 更新成功 ， { @ code false } 更新失败
     */
    @PutMapping("/update")
    @Operation(summary = "根据主键更新商户")
    public Result<Boolean> update(@RequestBody PayMerchant PayMerchant) {
        return Result.OK(PayMerchantService.updateById(PayMerchant));
    }


    /**
     * 查询所有商户
     *
     * @return Result.OK(所有数据
     */
    @GetMapping("/list")
    @Operation(summary = "查询所有商户")
    public Result<List<PayMerchant>> list() {
        return Result.OK(PayMerchantService.list());
    }


    /**
     * 根据商户主键获取详细信息。
     *
     * @param id PayMerchant主键
     * @return Result.OK(商户详情
     */
    @GetMapping("/getInfo/{id}")
    @Operation(summary = "根据商户主键获取详细信息")
    @Parameters(value = {
            @Parameter(name = "id", description = "id", required = true)
    })
    public Result<PayMerchant> getInfo(@PathVariable Serializable id) {
        return Result.OK(PayMerchantService.getById(id));
    }


    /**
     * 分页查询商户
     *
     * @param query 分页对象
     * @return Result.OK(分页对象
     */
    @GetMapping("/page")
    @Operation(summary = "分页查询商户")
    public Result<BasePage<PayMerchantVO>> page(@ParameterObject PayMerchantQuery query) {
        return Result.OK(PayMerchantService.queryPage(query));
    }
}