package pay.platform.api.system.controller;

import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.Parameters;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springdoc.core.annotations.ParameterObject;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import pay.platform.api.system.model.query.PayPlatformSettingQuery;
import pay.platform.api.system.model.vo.PayPlatformSettingVO;
import pay.platform.api.system.servcie.PayPlatformSettingService;
import pay.platform.core.common.Result;
import pay.platform.core.common.domain.BasePage;
import pay.platform.domain.PayPlatformSetting;

import java.io.Serializable;
import java.util.List;

/**
 * 平台配置 控制层。
 *
 * @author mybatis-flex-helper automatic generation
 * @since 1.0
 */
@RestController
@RequestMapping("/sys/pay/platform/setting")
@Tag(name = "平台配置控制层")
public class PayPlatformSettingController {

    @Autowired
    private PayPlatformSettingService PayPlatformSettingService;

    /**
     * 添加 平台配置
     *
     * @param PayPlatformSetting 平台配置
     * @ return Result.OK({@code true} 添加成功，{@code false} 添加失败
     */
    @PostMapping("/save")
    @Operation(summary = "添加平台配置")
    public Result<Boolean> save(@RequestBody PayPlatformSetting PayPlatformSetting) {
        return Result.OK(PayPlatformSettingService.save(PayPlatformSetting));
    }


    /**
     * 根据主键删除平台配置
     *
     * @param id 主键
     * @ return Result.OK({@code true} 删除成功，{@code false} 删除失败
     */
    @DeleteMapping("/remove/{id}")
    @Operation(summary = "根据主键删除平台配置")
    @Parameters(value = {
            @Parameter(name = "id", description = "id", required = true)
    })
    public Result<Boolean> remove(@PathVariable Serializable id) {
        return Result.OK(PayPlatformSettingService.removeById(id));
    }


    /**
     * 根据主键更新平台配置
     *
     * @param PayPlatformSetting 平台配置
     * @ return Result.OK({@code true} 更新成功，{@code false} 更新失败
     */
    @PutMapping("/update")
    @Operation(summary = "根据主键更新平台配置")
    public Result<Boolean> update(@RequestBody PayPlatformSetting PayPlatformSetting) {
        return Result.OK(PayPlatformSettingService.updateById(PayPlatformSetting));
    }


    /**
     * 查询所有平台配置
     *
     * @ return Result.OK(所有数据
     */
    @GetMapping("/list")
    @Operation(summary = "查询所有平台配置")
    public Result<List<PayPlatformSetting>> list() {
        return Result.OK(PayPlatformSettingService.list());
    }


    /**
     * 根据平台配置主键获取详细信息。
     *
     * @param id PayPlatformSetting主键
     * @ return Result.OK(平台配置详情
     */
    @GetMapping("/getInfo/{id}")
    @Operation(summary = "根据平台配置主键获取详细信息")
    @Parameters(value = {
            @Parameter(name = "id", description = "id", required = true)
    })
    public Result<PayPlatformSetting> getInfo(@PathVariable Serializable id) {
        return Result.OK(PayPlatformSettingService.getById(id));
    }


    /**
     * 分页查询平台配置
     *
     * @param query 分页对象
     * @ return Result.OK(分页对象
     */
    @GetMapping("/page")
    @Operation(summary = "分页查询平台配置")
    public Result<BasePage<PayPlatformSettingVO>> page(@ParameterObject PayPlatformSettingQuery query) {
        return Result.OK(PayPlatformSettingService.queryPage(query));
    }
}