package pay.platform.api.system.controller;

import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.Parameters;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springdoc.core.annotations.ParameterObject;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import pay.platform.api.system.model.query.PayChannelQuery;
import pay.platform.api.system.model.vo.PayChannelVO;
import pay.platform.api.system.servcie.PayChannelService;
import pay.platform.core.common.Result;
import pay.platform.core.common.domain.BasePage;
import pay.platform.domain.PayChannel;

import java.io.Serializable;
import java.util.List;

/**
 * 通道 控制层。
 *
 * @author mybatis-flex-helper automatic generation
 * @since 1.0
 */
@RestController
@RequestMapping("/sys/pay/channel")
@Tag(name = "通道控制层")
public class PayChannelController {

    @Autowired
    private PayChannelService PayChannelService;

    /**
     * 添加 通道
     *
     * @param PayChannel 通道
     * @return Result.OK({ @ code true } 添加成功 ， { @ code false } 添加失败
     */
    @PostMapping("/save")
    @Operation(summary = "添加通道")

    public Result<Boolean> save(@RequestBody PayChannel PayChannel) {
        return Result.OK(PayChannelService.savePayChannel(PayChannel));
    }


    /**
     * 根据主键删除通道
     *
     * @param id 主键
     * @return Result.OK({ @ code true } 删除成功 ， { @ code false } 删除失败
     */
    @DeleteMapping("/remove/{id}")
    @Operation(summary = "根据主键删除通道")
    @Parameters(value = {
            @Parameter(name = "id", description = "id", required = true)
    })
    public Result<Boolean> remove(@PathVariable Serializable id) {
        return Result.OK(PayChannelService.removeById(id));
    }


    /**
     * 根据主键更新通道
     *
     * @param PayChannel 通道
     * @return Result.OK({ @ code true } 更新成功 ， { @ code false } 更新失败
     */
    @PutMapping("/update")
    @Operation(summary = "根据主键更新通道")
    public Result<Boolean> update(@RequestBody PayChannel PayChannel) {
        return Result.OK(PayChannelService.updateById(PayChannel));
    }


    /**
     * 查询所有通道
     *
     * @return Result.OK(所有数据
     */
    @GetMapping("/list")
    @Operation(summary = "查询所有通道")
    public Result<List<PayChannel>> list() {
        return Result.OK(PayChannelService.list());
    }


    /**
     * 根据通道主键获取详细信息。
     *
     * @param id PayChannel主键
     * @return Result.OK(通道详情
     */
    @GetMapping("/getInfo/{id}")
    @Operation(summary = "根据通道主键获取详细信息")
    @Parameters(value = {
            @Parameter(name = "id", description = "id", required = true)
    })
    public Result<PayChannel> getInfo(@PathVariable Serializable id) {
        return Result.OK(PayChannelService.getById(id));
    }


    /**
     * 分页查询通道
     *
     * @param query 分页对象
     * @return Result.OK(分页对象
     */
    @GetMapping("/page")
    @Operation(summary = "分页查询通道")
    public Result<BasePage<PayChannelVO>> page(@ParameterObject PayChannelQuery query) {
        return Result.OK(PayChannelService.queryPage(query));
    }
}