package pay.platform.api.system.model.vo;

import io.swagger.v3.oas.annotations.media.Schema;
import jakarta.validation.constraints.Max;
import jakarta.validation.constraints.Min;
import jakarta.validation.constraints.NotBlank;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.ToString;
import pay.platform.core.enums.ConfigTypeEnums;
import pay.platform.core.enums.ValueEnum;

import java.io.Serializable;
import java.time.LocalDateTime;

/**
 * 配置
 */
@Data
@EqualsAndHashCode
@ToString
public class ConfigVO implements Serializable {
    @Schema(description = "主键")
    private String id;
    @Schema(description = "类型 1系统配置 2业务配置")
    @NotBlank(message = "类型不能为空")
    @Min(value = 1, message = "类型错误")
    @Max(value = 2, message = "类型错误")
    private Integer type;

    @Schema(description = "类型名称,只作用与响应数据")
    public String getTypeName() {
        if (null == type) {
            return "";
        }
        return ValueEnum.valueToEnum(ConfigTypeEnums.class, type, ConfigTypeEnums.CONFIG_TYPE01).getName();
    }

    @Schema(description = "配置项")
    private String code;
    @Schema(description = "配置值")
    private String value;
    @Schema(description = "备注")
    @Max(value = 255, message = "备注长度不能超过255")
    private String memo;
    /**
     * 创建人
     */
    @Schema(description = "创建人")
    protected String createUser;

    /**
     * 创建时间
     */
    @Schema(description = "创建时间")
    protected LocalDateTime createTime;

    /**
     * 更新人
     */
    @Schema(description = "更新人")
    protected String updateUser;

    /**
     * 更新时间
     */
    @Schema(description = "更新时间")
    protected LocalDateTime updateTime;
}
