package pay.platform.core.security.expression;

import org.springframework.beans.factory.ObjectProvider;
import org.springframework.security.config.core.GrantedAuthorityDefaults;
import org.springframework.stereotype.Service;
import pay.platform.core.security.model.Authority;
import pay.platform.core.security.util.SecurityUtil;

import java.util.Collection;
import java.util.List;

/**
 * 权限服务
 */
@Service("permission")
public class PermissionService {

    private final GrantedAuthorityDefaults grantedAuthorityDefaults;

    public PermissionService(ObjectProvider<GrantedAuthorityDefaults> provider) {
        grantedAuthorityDefaults = provider.getIfAvailable();
    }

    /**
     * 是否有对应的权限或者角色
     *
     * @param anyPermission 权限或者角色
     * @return 是否授权
     */
    public boolean hashPermission(String anyPermission) {
        Collection<Authority> authorities = SecurityUtil.getCurrentPermission();
        List<String> permission = authorities.stream().map(Authority::getAuthority).toList();
        String role = null;
        if (null != grantedAuthorityDefaults) {
            role = getRoleWithDefaultPrefix(grantedAuthorityDefaults.getRolePrefix(), anyPermission);
        }
        return permission.contains(role);
    }

    /**
     * 是否有对应的权限或者角色
     *
     * @param anyPermission 权限或者角色
     * @return 是否授权
     */
    public boolean hashPermission(String... anyPermission) {
        for (String permission : anyPermission) {
            if (hashPermission(permission)) {

                return true;
            }
        }
        return false;
    }

    private static String getRoleWithDefaultPrefix(String defaultRolePrefix, String role) {
        if (role == null) {
            return role;
        }
        if (defaultRolePrefix == null || defaultRolePrefix.isEmpty()) {
            return role;
        }
        if (role.startsWith(defaultRolePrefix)) {
            return role;
        }
        return defaultRolePrefix + role;
    }
}
