package pay.platform.api.controller;

import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import pay.platform.api.model.request.OrderRequest;
import pay.platform.api.model.request.PayRequest;
import pay.platform.api.model.response.OrderResponse;
import pay.platform.api.model.response.PayResponse;
import pay.platform.api.servcie.PayOrderService;
import pay.platform.api.servcie.PayService;
import pay.platform.core.common.Result;
import pay.platform.core.utils.SignUtil;

import java.util.TreeMap;

/**
 * 接口 - 支付
 */
@Slf4j
@RestController
@RequestMapping("/api")
@RequiredArgsConstructor
public class PayController {

    @Autowired
    private PayService payService;
    @Autowired
    private PayOrderService payOrderService;
    @PostMapping("/pay/alipay")
    public Result<PayResponse> pay(@RequestBody PayRequest payRequest) {
        log.info("payRequest:{}", payRequest);
        return Result.OK(payService.pay(payRequest));

    }


    @PostMapping("/query/order")
    public Result<OrderResponse> orderQuery(@RequestBody OrderRequest orderRequest) {
        log.info("orderRequest:{}", orderRequest);
        return Result.OK(payOrderService.queryOrder(orderRequest));
    }

    public static void main(String[] args) {
        String str = "{\n" +
                "\t\"orderNo\": \"1\",\n" +
                "\t\"amount\": \"0.01\",\n" +
                "\t\"subject\": \"购买商品\",\n" +
                "\t\"body\": \"测试下单\",\n" +
                "\t\"currentTime\": \"12345689\",\n" +
                "\t\"notifyUrl\": \"http://dsfsdfsdffdsfdsfds\",\n" +
                "\t\"appId\": \"123s1dfs54f5645456sfsfsf\"\n" +
                "}";
        TreeMap<String, String> treeMap = new TreeMap<>();
        treeMap.put("orderNo", "1");
        treeMap.put("amount", "0.01");
        treeMap.put("subject", "购买商品");
        treeMap.put("body", "测试下单");
        treeMap.put("currentTime", "12345689");
        treeMap.put("notifyUrl", "http://dsfsdfsdffdsfdsfds");
        treeMap.put("appId", "123s1dfs54f5645456sfsfsf");
        System.out.println(SignUtil.getSign("123s1dfs54f5645456sfsfsfasdffsd", treeMap));
    }
}
